@@ -179,6 +179,17 @@ class NetworkUtilsTest(test_base.BaseTestCase):
 
         self.assertFalse(netutils.is_valid_ip(''))
 
+    def test_is_valid_mac(self):
+        self.assertTrue(netutils.is_valid_mac("52:54:00:cf:2d:31"))
+        self.assertTrue(netutils.is_valid_mac(u"52:54:00:cf:2d:31"))
+        self.assertFalse(netutils.is_valid_mac("127.0.0.1"))
+        self.assertFalse(netutils.is_valid_mac("not:a:mac:address"))
+        self.assertFalse(netutils.is_valid_mac("52-54-00-cf-2d-31"))
+        self.assertFalse(netutils.is_valid_mac("aa bb cc dd ee ff"))
+        self.assertTrue(netutils.is_valid_mac("AA:BB:CC:DD:EE:FF"))
+        self.assertFalse(netutils.is_valid_mac("AA BB CC DD EE FF"))
+        self.assertFalse(netutils.is_valid_mac("AA-BB-CC-DD-EE-FF"))
+
     def test_is_valid_cidr(self):
         self.assertTrue(netutils.is_valid_cidr('10.0.0.0/24'))
         self.assertTrue(netutils.is_valid_cidr('10.0.0.1/32'))
@@ -191,6 +202,17 @@ class NetworkUtilsTest(test_base.BaseTestCase):
         self.assertFalse(netutils.is_valid_cidr('10.0.0.1/33'))
         self.assertFalse(netutils.is_valid_cidr(10))
 
+    def test_is_valid_ipv6_cidr(self):
+        self.assertTrue(netutils.is_valid_ipv6_cidr("2600::/64"))
+        self.assertTrue(netutils.is_valid_ipv6_cidr(
+            "abcd:ef01:2345:6789:abcd:ef01:192.168.254.254/48"))
+        self.assertTrue(netutils.is_valid_ipv6_cidr(
+            "0000:0000:0000:0000:0000:0000:0000:0001/32"))
+        self.assertTrue(netutils.is_valid_ipv6_cidr(
+            "0000:0000:0000:0000:0000:0000:0000:0001"))
+        self.assertFalse(netutils.is_valid_ipv6_cidr("foo"))
+        self.assertFalse(netutils.is_valid_ipv6_cidr("127.0.0.1"))
+
     def test_valid_port(self):
         valid_inputs = [0, '0', 1, '1', 2, '3', '5', 8, 13, 21,
                         '80', '3246', '65535']
